dnsaf: Calculate dNSAF

Description Usage Arguments Examples

View source: R/dnsaf_functions.R

Description

This function calculates distributed normalized spectral abundance factor from a percolator target psms file

Usage

1
2
dnsaf(percolatorFile, fasta, test_run = F, q_cutoff = 0.01,
  nonUniqueDummyCount = 0.5)

Arguments

percolatorFile

a tibble read from the percolator target psms file

fasta

a Biostrings AA string set containing a proteomics database used in the search

test_run

Whether to do a short run of only 100 search results? Defaults to FALSE

q_cutoff

Percolator q vsalue cutoff to consider as confident peptide. Defaults to 0.01

nonUniqueDummyCount

Unique counts to give to a protein without unique peptide. Defaults to 0.5

Examples

1
calcDNSAF::dnsaf(percolatorFile = percolatorFile, fasta = Mm_UniProt, test_run=T, q_cutoff=0.01)

ed-lau/calcDNSAF documentation built on Nov. 4, 2019, 11:29 a.m.