Description Usage Arguments Examples
View source: R/dnsaf_functions.R
This function calculates distributed normalized spectral abundance factor from a percolator target psms file
1 2 | dnsaf(percolatorFile, fasta, test_run = F, q_cutoff = 0.01,
nonUniqueDummyCount = 0.5)
|
percolatorFile |
a tibble read from the percolator target psms file |
fasta |
a Biostrings AA string set containing a proteomics database used in the search |
test_run |
Whether to do a short run of only 100 search results? Defaults to FALSE |
q_cutoff |
Percolator q vsalue cutoff to consider as confident peptide. Defaults to 0.01 |
nonUniqueDummyCount |
Unique counts to give to a protein without unique peptide. Defaults to 0.5 |
1 | calcDNSAF::dnsaf(percolatorFile = percolatorFile, fasta = Mm_UniProt, test_run=T, q_cutoff=0.01)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.